==> nateon-1.0.1.192.tar.bz2: nateon-1.0/messagebox/messageboxdcop.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef MESSAGEBOXDCOP_H
#define MESSAGEBOXDCOP_H

#include <dcopobject.h>
#include <qstring.h>

/**
	@author 장두현 <ring0320@nate.com>
*/
class MessageBoxDCOP : virtual public DCOPObject
{
K_DCOP
public:
k_dcop:
  // MessageBoxDCOP();
  // ~MessageBoxDCOP();
  virtual void setUserID( const QString s ) = 0;
  virtual void setDBPath( const QString s ) = 0;
	virtual void setDefaultBrowser( const QString s ) = 0;
  virtual void dcopCommand( const QString s ) = 0;
};

#endif

==> nateon-1.0.1.275.tar.bz2: nateon-1.0/messagebox/messageboxdcop.h <==
/***************************************************************************
 *   Copyright (C) 2008 by SK Communications.                              *
 *   http://kldp.net/projects/nateon/                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef MESSAGEBOXDCOP_H
#define MESSAGEBOXDCOP_H

#include <dcopobject.h>
#include <qstring.h>

/**
	@author 장두현 <ring0320@nate.com>
*/
class MessageBoxDCOP : virtual public DCOPObject {
    K_DCOP
public:
k_dcop:
    // MessageBoxDCOP();
    // ~MessageBoxDCOP();
    virtual void setUserID( const QString s ) = 0;
    virtual void setDBPath( const QString s ) = 0;
    virtual void setDefaultBrowser( const QString s ) = 0;
    virtual void dcopCommand( const QString s ) = 0;
};

#endif
